@@ -552,11 +552,12 @@ tabnet_train_supervised <- function(obj, x, y, config = tabnet_config(), epoch_s
       if (config$verbose) pb$tick(tokens = m)
       train_metrics <- c(train_metrics, m)
     })
-    metrics[[epoch]][["train"]] <- transpose_metrics(train_metrics)
+    metrics[[epoch]][["train"]] <- transpose_metrics(train_metrics)$loss
 
     if (config$checkpoint_epochs > 0 && epoch %% config$checkpoint_epochs == 0) {
       network$to(device = "cpu")
       checkpoints[[length(checkpoints) + 1]] <- model_to_raw(network)
+      metrics[[epoch]][["checkpoint"]] <- TRUE
       network$to(device = device)
     }
 
@@ -566,20 +567,20 @@ tabnet_train_supervised <- function(obj, x, y, config = tabnet_config(), epoch_s
         m <- valid_batch(network, to_device(batch, device), config)
         valid_metrics <- c(valid_metrics, m)
       })
-      metrics[[epoch]][["valid"]] <- transpose_metrics(valid_metrics)
+      metrics[[epoch]][["valid"]] <- transpose_metrics(valid_metrics)$loss
     }
 
     if (config$verbose & !has_valid)
-      message(gettextf("[Epoch %03d] Loss: %3f", epoch, mean(metrics[[epoch]]$train$loss)))
+      message(gettextf("[Epoch %03d] Loss: %3f", epoch, mean(metrics[[epoch]]$train)))
     if (config$verbose & has_valid)
-      message(gettextf("[Epoch %03d] Loss: %3f, Valid loss: %3f", epoch, mean(metrics[[epoch]]$train$loss), mean(metrics[[epoch]]$valid$loss)))
+      message(gettextf("[Epoch %03d] Loss: %3f, Valid loss: %3f", epoch, mean(metrics[[epoch]]$train), mean(metrics[[epoch]]$valid)))
 
 
     # Early-stopping checks
     if (config$early_stopping && config$early_stopping_monitor=="valid_loss"){
-      current_loss <- mean(metrics[[epoch]]$valid$loss)
+      current_loss <- mean(metrics[[epoch]]$valid)
     } else {
-      current_loss <- mean(metrics[[epoch]]$train$loss)
+      current_loss <- mean(metrics[[epoch]]$train)
     }
     if (config$early_stopping && epoch > 1+epoch_shift) {
       # compute relative change, and compare to best_metric
